==> zio-aws-iot1clickdevices_2.13-5.17.123.2-sources.jar: zio/aws/iot1clickdevices/model/FinalizeDeviceClaimResponse.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class FinalizeDeviceClaimResponse(state: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse = {
    import FinalizeDeviceClaimResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
      .builder()
      .optionallyWith(
        state.map(value => __string.unwrap(value): java.lang.String)
      )(_.state)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse.ReadOnly =
    zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse
      .wrap(buildAwsValue())
}
object FinalizeDeviceClaimResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse =
      zio.aws.iot1clickdevices.model
        .FinalizeDeviceClaimResponse(state.map(value => value))
    def state: Option[__string]
    def getState: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
  ) extends zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse.ReadOnly {
    override val state: Option[__string] = scala
      .Option(impl.state())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
  ): zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.153.2-sources.jar: zio/aws/iot1clickdevices/model/FinalizeDeviceClaimResponse.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class FinalizeDeviceClaimResponse(state: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse = {
    import FinalizeDeviceClaimResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
      .builder()
      .optionallyWith(state.map(value => value: java.lang.String))(_.state)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse.ReadOnly =
    zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse
      .wrap(buildAwsValue())
}
object FinalizeDeviceClaimResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse =
      zio.aws.iot1clickdevices.model
        .FinalizeDeviceClaimResponse(state.map(value => value))
    def state: Option[__string]
    def getState: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
  ) extends zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse.ReadOnly {
    override val state: Option[__string] =
      scala.Option(impl.state()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.FinalizeDeviceClaimResponse
  ): zio.aws.iot1clickdevices.model.FinalizeDeviceClaimResponse.ReadOnly =
    new Wrapper(impl)
}
